@@ -79,9 +79,9 @@ def _load_classes(locations, classes):
         abs_path = abs_path.replace('translator/hot', cls_path)
 
         # Grab all the tosca type module files in the given path
-        mod_files = [f for f in os.listdir(abs_path) if f.endswith('.py')
-                     and not f.startswith('__init__')
-                     and f.startswith('tosca_')]
+        mod_files = [f for f in os.listdir(abs_path) if f.endswith('.py') and
+                     not f.startswith('__init__') and
+                     f.startswith('tosca_')]
 
         # For each module, pick out the target translation class
         for f in mod_files:
@@ -276,6 +276,9 @@ class TranslateNodeTemplates(object):
             if policy.is_derived_from('tosca.policies.Placement'):
                 TOSCA_TO_HOT_TYPE[policy_type.type] = \
                     TOSCA_TO_HOT_TYPE['tosca.policies.Placement']
+            if policy.is_derived_from('tosca.policies.Reservation'):
+                TOSCA_TO_HOT_TYPE[policy_type.type] = \
+                    TOSCA_TO_HOT_TYPE['tosca.policies.Reservation']
             if policy_type.type not in TOSCA_TO_HOT_TYPE:
                 raise UnsupportedTypeError(type=_('%s') % policy_type.type)
             elif policy_type.type == 'tosca.policies.Scaling.Cluster':
